==> opencascade_7.8.1+dfsg1.orig.tar.xz: occt-V7_8_1/src/StepBasic/StepBasic_PersonAndOrganization.cxx <==
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.


#include <StepBasic_Organization.hxx>
#include <StepBasic_Person.hxx>
#include <StepBasic_PersonAndOrganization.hxx>

IMPLEMENT_STANDARD_RTTIEXT(StepBasic_PersonAndOrganization,Standard_Transient)

StepBasic_PersonAndOrganization::StepBasic_PersonAndOrganization ()  {}

void StepBasic_PersonAndOrganization::Init(
	const Handle(StepBasic_Person)& aThePerson,
	const Handle(StepBasic_Organization)& aTheOrganization)
{
	// --- classe own fields ---
	thePerson = aThePerson;
	theOrganization = aTheOrganization;
}


void StepBasic_PersonAndOrganization::SetThePerson(const Handle(StepBasic_Person)& aThePerson)
{
	thePerson = aThePerson;
}

Handle(StepBasic_Person) StepBasic_PersonAndOrganization::ThePerson() const
{
	return thePerson;
}

void StepBasic_PersonAndOrganization::SetTheOrganization(const Handle(StepBasic_Organization)& aTheOrganization)
{
	theOrganization = aTheOrganization;
}

Handle(StepBasic_Organization) StepBasic_PersonAndOrganization::TheOrganization() const
{
	return theOrganization;
}

==> opencascade_7.9.2+dfsg.orig.tar.xz: occt-V7_9_2/src/StepBasic/StepBasic_PersonAndOrganization.cxx <==
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <StepBasic_Organization.hxx>
#include <StepBasic_Person.hxx>
#include <StepBasic_PersonAndOrganization.hxx>

IMPLEMENT_STANDARD_RTTIEXT(StepBasic_PersonAndOrganization, Standard_Transient)

StepBasic_PersonAndOrganization::StepBasic_PersonAndOrganization() {}

void StepBasic_PersonAndOrganization::Init(const Handle(StepBasic_Person)&       aThePerson,
                                           const Handle(StepBasic_Organization)& aTheOrganization)
{
  // --- classe own fields ---
  thePerson       = aThePerson;
  theOrganization = aTheOrganization;
}

void StepBasic_PersonAndOrganization::SetThePerson(const Handle(StepBasic_Person)& aThePerson)
{
  thePerson = aThePerson;
}

Handle(StepBasic_Person) StepBasic_PersonAndOrganization::ThePerson() const
{
  return thePerson;
}

void StepBasic_PersonAndOrganization::SetTheOrganization(
  const Handle(StepBasic_Organization)& aTheOrganization)
{
  theOrganization = aTheOrganization;
}

Handle(StepBasic_Organization) StepBasic_PersonAndOrganization::TheOrganization() const
{
  return theOrganization;
}
